@@ -25,7 +25,7 @@
 #include <iostream>
 using namespace std;
 
-#include "rtty.h"
+//#include "rtty.h"
 #include "view_rtty.h"
 #include "fl_digi.h"
 #include "digiscope.h"
@@ -57,10 +57,13 @@ static char figures[32] = {
 	'9',	'?',	'&',	' ',	'.',	'/',	';',	' '
 };
 
-const double view_rtty::SHIFT[] = {23, 85, 160, 170, 182, 200, 240, 350, 425, 850};
-const double view_rtty::BAUD[]  = {45, 45.45, 50, 56, 75, 100, 110, 150, 200, 300};
-const int    view_rtty::BITS[]  = {5, 7, 8};
-const int view_rtty::numshifts = (int)(sizeof(SHIFT) / sizeof(*SHIFT));
+const double	view_rtty::SHIFT[] = {23, 85, 160, 170, 182, 200, 240, 350, 425, 850};
+// FILTLEN must be same size as BAUD
+const double	view_rtty::BAUD[]  = {45, 45.45, 50, 56, 75, 100, 110, 150, 200, 300};
+const int		view_rtty::FILTLEN[] = { 512, 512, 512, 512, 512, 512, 512, 256, 128, 64};
+const int		view_rtty::BITS[]  = {5, 7, 8};
+const int		view_rtty::numshifts = (int)(sizeof(SHIFT) / sizeof(*SHIFT));
+const int		view_rtty::numbauds = (int)(sizeof(BAUD) / sizeof(*BAUD));
 
 void view_rtty::rx_init()
 {
@@ -82,7 +85,7 @@ void view_rtty::rx_init()
 
 		channel[ch].inp_ptr = 0;
 
-		for (int i = 0; i < MAXPIPE; i++)
+		for (int i = 0; i < VIEW_MAXPIPE; i++)
 			channel[ch].mark_history[i] =
 			channel[ch].space_history[i] = cmplx(0,0);
 	}
@@ -107,20 +110,12 @@ view_rtty::~view_rtty()
 
 void view_rtty::reset_filters(int ch)
 {
-	int filter_length = 1024;
-	if (channel[ch].mark_filt) {
-		channel[ch].mark_filt->rtty_filter(rtty_baud/samplerate);
-	} else {
-		channel[ch].mark_filt = new fftfilt(rtty_baud/samplerate, filter_length);
-		channel[ch].mark_filt->rtty_filter(rtty_baud/samplerate);
-	}
-
-	if (channel[ch].space_filt) {
-		channel[ch].space_filt->rtty_filter(rtty_baud/samplerate);
-	} else {
-		channel[ch].space_filt = new fftfilt(rtty_baud/samplerate, filter_length);
-		channel[ch].space_filt->rtty_filter(rtty_baud/samplerate);
-	}
+	delete channel[ch].mark_filt;
+	channel[ch].mark_filt = new fftfilt(rtty_baud/samplerate, filter_length);
+	channel[ch].mark_filt->rtty_filter(rtty_baud/samplerate);
+	delete channel[ch].space_filt;
+	channel[ch].space_filt = new fftfilt(rtty_baud/samplerate, filter_length);
+	channel[ch].space_filt->rtty_filter(rtty_baud/samplerate);
 }
 
 void view_rtty::restart()
@@ -130,6 +125,8 @@ void view_rtty::restart()
 	rtty_shift = shift = (progdefaults.rtty_shift < rtty::numshifts ?
 			      SHIFT[progdefaults.rtty_shift] : progdefaults.rtty_custom_shift);
 	rtty_baud = BAUD[progdefaults.rtty_baud];
+	filter_length = FILTLEN[progdefaults.rtty_baud];
+
 	nbits = rtty_bits = BITS[progdefaults.rtty_bits];
 	if (rtty_bits == 5)
 		rtty_parity = RTTY_PARITY_NONE;
@@ -187,7 +184,7 @@ void view_rtty::restart()
 
 		for (int i = 0; i < VIEW_RTTY_MAXBITS; i++) channel[ch].bit_buf[i] = 0.0;
 
-		for (int i = 0; i < MAXPIPE; i++)
+		for (int i = 0; i < VIEW_MAXPIPE; i++)
 			channel[ch].mark_history[i] = channel[ch].space_history[i] = cmplx(0,0);
 	}
 
@@ -521,14 +518,14 @@ int view_rtty::rx_process(const double *buf, int buflen)
 
 				channel[ch].mark_history[channel[ch].inp_ptr] = zp_mark[i];
 				channel[ch].space_history[channel[ch].inp_ptr] = zp_space[i];
-				channel[ch].inp_ptr = (channel[ch].inp_ptr + 1) % MAXPIPE;
+				channel[ch].inp_ptr = (channel[ch].inp_ptr + 1) % VIEW_MAXPIPE;
 
 				if (channel[ch].state == RCVNG && rx( ch, reverse ? !bit : bit ) ) {
 					if (channel[ch].sigsearch) channel[ch].sigsearch--;
 					int mp0 = channel[ch].inp_ptr - 2;
 					int mp1 = mp0 + 1;
-					if (mp0 < 0) mp0 += MAXPIPE;
-					if (mp1 < 0) mp1 += MAXPIPE;
+					if (mp0 < 0) mp0 += VIEW_MAXPIPE;
+					if (mp1 < 0) mp1 += VIEW_MAXPIPE;
 					double ferr = (TWOPI * samplerate / rtty_baud) *
 						(!reverse ?
 						arg(conj(channel[ch].mark_history[mp1]) * channel[ch].mark_history[mp0]) :
