@@ -65,7 +65,7 @@ Murray Greenman      ZL1BPU<br>\n\
 Espa\361ol     Spanish      Pavel Milanes Costa CO7WT\n\
                          Christian W. Correa HK4QWC\n\
 Deutsch     German       Marc Richter        DF2MR\n\
-Fran\347ais    French       St\351phane Fillod     F8CFE\n\
+Fran\347ais    French       Bernard Seront      F4GAR\n\
 Italiano    Italian      Pierfrancesco Caci  IK5PVX\n\
 Język       Polish       Roman Bagiński      SP4JEU\n\
 Nederlands  Dutch        Peter van der Post  PA1POS\n\
