@@ -116,9 +116,10 @@ public:
 	void		setFont(Fl_Font f, int attr = NATTR);
 
 protected:
-	enum { TX_MENU_TX, TX_MENU_RX, TX_MENU_ABORT, TX_MENU_MFSK16_IMG,
-	       TX_MENU_CUT, TX_MENU_COPY, TX_MENU_PASTE, TX_MENU_CLEAR, TX_MENU_READ,
-	       TX_MENU_WRAP
+	enum { TX_MENU_TX, TX_MENU_RX, TX_MENU_ABORT,
+			TX_MENU_MFSK16_IMG,
+			TX_MENU_CUT, TX_MENU_COPY, TX_MENU_PASTE, TX_MENU_CLEAR,
+			TX_MENU_READ, TX_MENU_WRAP
 	};
 	int		handle_key_shortcuts(int key);
 	int		handle_key(int key);
