@@ -120,8 +120,14 @@ extern Fl_Group		*QsoInfoFrame1B;
 extern Fl_Group		*qsoFrameView;
 extern Fl_Group		*QsoInfoFrame;
 extern cFreqControl	*qsoFreqDisp;
+extern Fl_Group		*qso_combos;
 extern Fl_ComboBox		*qso_opMODE;
+extern Fl_Group		*qso_opGROUP;
 extern Fl_ComboBox		*qso_opBW;
+extern Fl_Button		*qso_btnBW1;
+extern Fl_ComboBox		*qso_opBW1;
+extern Fl_Button		*qso_btnBW2;
+extern Fl_ComboBox		*qso_opBW2;
 extern Fl_Button		*qso_opPICK;
 extern Fl_Browser		*qso_opBrowser;
 
@@ -188,11 +194,31 @@ extern void			clear_heard_list();
 extern void			age_heard_list();
 extern void			add_to_heard_list(std::string, std::string);
 extern void			fsq_transmit_string(std::string s);
+extern void			fsq_xmt_mt(void *s);
+extern void			fsq_xmt(std::string s);
 extern void			fsq_repeat_last_heard();
 extern void			fsq_repeat_last_command();
 extern void 			display_fsq_rx_text(std::string text, int style = FTextBase::SKIP);
 extern void			display_fsq_mon_text(std::string text, int style = FTextBase::SKIP);
 
+extern Fl_Group		*ifkp_group;
+extern Fl_Group		*ifkp_upper;
+extern Fl_Group		*ifkp_upper_left;
+extern FTextRX			*ifkp_rx_text;
+extern Fl_Group		*ifkp_upper_right;
+extern Fl_Browser		*ifkp_heard;
+extern Progress		*ifkp_s2n_progress;
+extern Fl_Group		*ifkp_lower;
+extern FTextTX			*ifkp_tx_text;
+extern picture			*ifkp_avatar;
+int						ifkp_load_avatar(std::string image_fname = "", int W=59, int H=74);
+extern					void ifkp_clear_avatar();
+extern					void ifkp_update_avatar(unsigned char data, int pos);
+extern					int ifkp_get_avatar_pixel(int pos, int color);
+extern					void cb_ifkp_send_avatar( Fl_Widget *w, void *);
+
+extern void			cb_ifkp_heard(Fl_Browser*, void*);
+
 extern void			enableSELCAL();
 
 extern void			cbFSQQTC(Fl_Widget *w, void *d);
@@ -201,6 +227,10 @@ extern void			cbMONITOR(Fl_Widget *w, void *d);
 extern void			cbSELCAL(Fl_Widget *w, void *d);
 extern void			cbFSQCALL(Fl_Widget *w, void *d);
 
+extern void			ifkp_showTxViewer(char C = 'T');
+extern Fl_Double_Window	*ifkppicRxWin;
+extern Fl_Double_Window	*ifkppicTxWin;
+
 #include <FL/Fl_Bitmap.H>
 extern Fl_Bitmap image_s2n;
 
@@ -306,8 +336,12 @@ extern void put_Status1(const char *msg, double timeout = 0.0, status_timeout ac
 extern void put_Status2(const char *msg, double timeout = 0.0, status_timeout action = STATUS_CLEAR);
 
 extern void show_frequency(long long);
-extern void show_mode(const std::string& mode);
-extern void show_bw(const std::string& sWidth);
+
+extern void show_mode(const std::string sMode);
+extern void show_bw(const std::string sWidth);
+extern void show_bw1(const std::string sVal);
+extern void show_bw2(const std::string sVal);
+
 extern void show_spot(bool v);
 extern void showMacroSet();
 extern void setwfrange();
@@ -429,6 +463,7 @@ extern bool xml_get_record(const char *);
 
 extern const char* zdate(void);
 extern const char* ztime(void);
+extern void ztimer(void* first_call);
 
 extern void setTabColors();
 
