@@ -45,7 +45,7 @@ friend std::ostream &operator<<( std::ostream &, const cQsoRec &);
 friend std::istream &operator>>( std::istream &, cQsoRec & );
 
 private:
-	string qsofield[NUMFIELDS];
+	string *qsofield[NUMFIELDS];
 	//bool normal; // sort ordering
 public:
 	cQsoRec ();
