@@ -47,6 +47,10 @@ extern void buildlist();
 extern void qso_movFreq(Fl_Widget* w, void*);
 extern int	cb_qso_opMODE();
 extern int  cb_qso_opBW();
+extern int  cb_qso_btnBW1();
+extern int  cb_qso_opBW1();
+extern int  cb_qso_btnBW2();
+extern int  cb_qso_opBW2();
 extern void qso_setMode();
 extern void setTitle();
 
@@ -63,6 +67,8 @@ extern bool readRigXML();
 extern bool init_Xml_RigDialog();
 extern bool init_NoRig_RigDialog();
 
+extern bool ModeIsLSB(std::string);
+
 #if USE_HAMLIB
 extern bool init_Hamlib_RigDialog();
 extern void selMode(rmode_t m);
