@@ -37,6 +37,7 @@
 #include "filters.h"
 #include "fftfilt.h"
 #include "digiscope.h"
+#include "view_rtty.h"
 
 #define	RTTY_SampleRate	8000
 //#define RTTY_SampleRate 11025
@@ -50,23 +51,6 @@
 
 #define dispwidth 100
 
-enum RTTY_RX_STATE {
-	RTTY_RX_STATE_IDLE = 0,
-	RTTY_RX_STATE_START,
-	RTTY_RX_STATE_DATA,
-	RTTY_RX_STATE_PARITY,
-	RTTY_RX_STATE_STOP,
-	RTTY_RX_STATE_STOP2
-};
-
-enum RTTY_PARITY {
-	RTTY_PARITY_NONE = 0,
-	RTTY_PARITY_EVEN,
-	RTTY_PARITY_ODD,
-	RTTY_PARITY_ZERO,
-	RTTY_PARITY_ONE
-};
-
 // simple oscillator-class
 class Oscillator
 {
@@ -118,10 +102,28 @@ private:
 
 class rtty : public modem {
 public:
-	static const double SHIFT[];
-	static const double BAUD[];
-	static const int	BITS[];
-	static const int numshifts;
+enum RTTY_RX_STATE {
+	RTTY_RX_STATE_IDLE = 0,
+	RTTY_RX_STATE_START,
+	RTTY_RX_STATE_DATA,
+	RTTY_RX_STATE_PARITY,
+	RTTY_RX_STATE_STOP,
+	RTTY_RX_STATE_STOP2
+};
+enum RTTY_PARITY {
+	RTTY_PARITY_NONE = 0,
+	RTTY_PARITY_EVEN,
+	RTTY_PARITY_ODD,
+	RTTY_PARITY_ZERO,
+	RTTY_PARITY_ONE
+};
+
+	static const double	SHIFT[];
+	static const double	BAUD[];
+	static const int		BITS[];
+	static const int		FILTLEN[];
+	static const int		numshifts;
+	static const int		numbauds;
 
 private:
 
@@ -159,6 +161,7 @@ private:
 	double space_phase;
 	fftfilt *mark_filt;
 	fftfilt *space_filt;
+	int filter_length;
 
 	double *pipe;
 	double *dsppipe;
@@ -217,6 +220,9 @@ private:
 	int decode_char();
 	int rttyparity(unsigned int);
 	bool rx(bool bit);
+
+	view_rtty *rttyviewer;
+
 // transmit
 	double nco(double freq);
 	void send_symbol(int symbol, int len);
@@ -243,6 +249,10 @@ public:
 	int tx_process();
 	void flush_stream();
 
+	void clear_viewer() { rttyviewer->clear(); }
+	void clear_ch(int n) { rttyviewer->clearch(n); }
+	int  viewer_get_freq(int n) { return rttyviewer->get_freq(n); }
+
 	void searchDown();
 	void searchUp();
 
