@@ -275,13 +275,17 @@ void adif_read_OK()
 void cb_mnuOpenLogbook(Fl_Menu_* m, void* d)
 {
 	string title = _("Open logbook file");
-	string filters;
-	filters.assign("ADIF\t*.").append(ADIF_SUFFIX);
+	string filter;
+	filter.assign("ADIF file\t*.").append(ADIF_SUFFIX);
 #ifdef __APPLE__
-	filters.append("\n");
+	filter.append("\n");
 #endif
 
-	const char* p = FSEL::select( title.c_str(), filters.c_str(), logbook_filename.c_str());
+	std::string deffilename = LogsDir;
+	deffilename.append(fl_filename_name(logbook_filename.c_str()));
+
+	const char* p = FSEL::select( title.c_str(), filter.c_str(), deffilename.c_str());
+
 	if (p) {
 		saveLogbook();
 		qsodb.deleteRecs();
@@ -303,11 +307,19 @@ void cb_mnuSaveLogbook(Fl_Menu_*m, void* d) {
 #ifdef __APPLE__
 	filter.append("\n");
 #endif
-	const char* p = FSEL::saveas( title.c_str(), filter.c_str(), logbook_filename.c_str());
+	std::string deffilename = LogsDir;
+	deffilename.append(fl_filename_name(logbook_filename.c_str()));
+
+	const char* p = FSEL::select( title.c_str(), filter.c_str(), deffilename.c_str());
+
 	if (p) {
 		logbook_filename = p;
 		if (logbook_filename.find("." ADIF_SUFFIX) == string::npos)
 			logbook_filename.append("." ADIF_SUFFIX);
+
+		progdefaults.logbookfilename = logbook_filename;
+		progdefaults.changed = true;
+
 		dlgLogbook->label(fl_filename_name(logbook_filename.c_str()));
 
 		cQsoDb::reverse = false;
@@ -491,7 +503,7 @@ void merge_recs( cQsoDb *db, cQsoDb *mrgdb ) // (haystack, needle)
 }
 
 void cb_mnuMergeADIF_log(Fl_Menu_* m, void* d) {
-	const char* p = FSEL::select(_("Merge ADIF file"), "ADIF\t*." ADIF_SUFFIX);
+	const char* p = FSEL::select(_("Merge ADIF file"), "ADIF\t*." ADIF_SUFFIX, LogsDir.c_str());
 	Fl::wait();
 	fl_digi_main->redraw();
 	Fl::awake();
@@ -539,7 +551,7 @@ void cb_Export_log() {
 	chkExportBrowser->textfont(FL_SCREEN_BOLD);
 	chkExportBrowser->textsize(12);
 #else
-	chkExportBrowser->textfont(FL_SCREEN);
+	chkExportBrowser->textfont(FL_COURIER);
 	chkExportBrowser->textsize(12);
 #endif
 	for( int i = 0; i < qsodb.nbrRecs(); i++ ) {
@@ -787,9 +799,9 @@ void SearchLastQSO(const char *callsign)
 			double lon1, lat1, lon2, lat2;
 			double azimuth, distance;
 			char szAZ[4];
-			if ( locator2longlat(&lon1, &lat1, progdefaults.myLocator.c_str()) == RIG_OK &&
-				 locator2longlat(&lon2, &lat2, inpLoc->value()) == RIG_OK &&
-				 qrb(lon1, lat1, lon2, lat2, &distance, &azimuth) == RIG_OK ) {
+			if ( QRB::locator2longlat(&lon1, &lat1, progdefaults.myLocator.c_str()) == QRB::QRB_OK &&
+				 QRB::locator2longlat(&lon2, &lat2, inpLoc->value()) == QRB::QRB_OK &&
+				 QRB::qrb(lon1, lat1, lon2, lat2, &distance, &azimuth) == QRB::QRB_OK ) {
 				snprintf(szAZ,sizeof(szAZ),"%0.f", azimuth);
 				inpAZ->value(szAZ);
 			} else
@@ -1314,8 +1326,13 @@ void cb_Export_Cabrillo(Fl_Menu_* m, void* d) {
 	}
 	cboContest->index(0);
 	chkCabBrowser->clear();
+#ifdef __APPLE__
 	chkCabBrowser->textfont(FL_SCREEN_BOLD);
 	chkCabBrowser->textsize(12);
+#else
+	chkCabBrowser->textfont(FL_COURIER);
+	chkCabBrowser->textsize(12);
+#endif
 	for( int i = 0; i < qsodb.nbrRecs(); i++ ) {
 		rec = qsodb.getRec (i);
 		memset(line, 0, sizeof(line));
@@ -1325,6 +1342,7 @@ void cb_Export_Cabrillo(Fl_Menu_* m, void* d) {
  			rec->getField(CALL),
 			szfreq(rec->getField(FREQ)),
 			rec->getField(MODE) );
+std::cout << line << "\n";
         chkCabBrowser->add(line);
 	}
 	wCabrillo->show();
