@@ -137,9 +137,9 @@ bool xml_get_record(const char *callsign)
 		double lon1, lat1, lon2, lat2;
 		double azimuth, distance;
 		char szAZ[4];
-		if ( locator2longlat(&lon1, &lat1, progdefaults.myLocator.c_str()) == RIG_OK &&
-			 locator2longlat(&lon2, &lat2, inpLoc->value()) == RIG_OK &&
-			 qrb(lon1, lat1, lon2, lat2, &distance, &azimuth) == RIG_OK ) {
+		if ( QRB::locator2longlat(&lon1, &lat1, progdefaults.myLocator.c_str()) == QRB::QRB_OK &&
+			 QRB::locator2longlat(&lon2, &lat2, inpLoc->value()) == QRB::QRB_OK &&
+			 QRB::qrb(lon1, lat1, lon2, lat2, &distance, &azimuth) == QRB::QRB_OK ) {
 			snprintf(szAZ,sizeof(szAZ),"%0.f", azimuth);
 			inpAZ->value(szAZ);
 		} else
@@ -278,14 +278,10 @@ bool xml_check_dup()
 
 void connect_to_log_server(void *)
 {
-	if (!log_client) {
-		int xmllog_port = atoi(progdefaults.xmllog_port.c_str());
-		log_client = new XmlRpcClient(progdefaults.xmllog_address.c_str(), xmllog_port);
-	} else {
-		delete log_client;
-		int xmllog_port = atoi(progdefaults.xmllog_port.c_str());
-		log_client = new XmlRpcClient(progdefaults.xmllog_address.c_str(), xmllog_port);
-	}
+	if (log_client) delete log_client;
+	log_client = new XmlRpcClient(
+					progdefaults.xmllog_address.c_str(),
+					atoi(progdefaults.xmllog_port.c_str()));
 
 	if (progdefaults.xml_logbook) {
 		if (test_connection(true)) {
