@@ -129,6 +129,7 @@ string ScriptsDir = "";
 string PalettesDir = "";
 string LogsDir = "";
 string PicsDir = "";
+string AvatarDir = "";
 string HelpDir = "";
 string MacrosDir = "";
 string WrapDir = "";
@@ -350,6 +351,9 @@ void delayed_startup(void *)
 	if (progdefaults.check_for_updates)
 		cb_mnuCheckUpdate((Fl_Widget *)0, NULL);
 
+#if USE_PORTAUDIO
+	LOG_INFO("%s", str_pa_devices.c_str());
+#endif
 }
 
 int main(int argc, char ** argv)
@@ -357,6 +361,9 @@ int main(int argc, char ** argv)
 	// for KISS_IO status information
 	program_start_time = time(0);
 
+	// ztimer must be run by FLTK's timeout handler
+	ztimer((void*)true);
+
 	active_modem = new NULLMODEM;
 
 	string appdir = appname = argv[0];
@@ -1571,6 +1578,7 @@ static void checkdirectories(void)
 		{ PalettesDir, "palettes", create_new_palettes },
 		{ LogsDir, "logs", 0 },
 		{ PicsDir, "images", 0 },
+		{ AvatarDir, "avatars", 0},
 		{ HelpDir, "help", 0 },
 		{ MacrosDir, "macros", create_new_macros },
 		{ WrapDir, "wrap", 0 },
