@@ -772,12 +772,14 @@ bool Socket_arqRx()
 
 void WriteARQ(unsigned char data)
 {
+	if (active_modem->get_mode() == MODE_FSQ) return;
 	guard_lock tosend_lock(&tosend_mutex);
 	tosend += data;
 }
 
 void WriteARQ(const char *data)
 {
+	if (active_modem->get_mode() == MODE_FSQ) return;
 	guard_lock tosend_lock(&tosend_mutex);
 	tosend.append(data);
 }
@@ -833,6 +835,11 @@ static void *arq_loop(void *args)
 	return NULL;
 }
 
+bool arq_state(void)
+{
+	return arq_enabled;
+}
+
 void arq_init()
 {
 	arq_enabled = false;
