@@ -106,6 +106,7 @@ std::string text2repeat = "";
 size_t repeatchar = 0;
 
 bool macro_idle_on = false;
+bool macro_rx_wait = false;
 
 static float  idleTime = 0;
 static bool TransmitON = false;
@@ -122,9 +123,14 @@ static bool GET = false;
 static bool timed_exec = false;
 static bool within_exec = false;
 
+void rx_que_continue(void *);
+
 static void postQueue(std::string s)
 {
-	ReceiveText->addstr(s, FTextBase::CTRL);
+	if (active_modem->get_mode() == MODE_IFKP)
+		ifkp_rx_text->addstr(s, FTextBase::CTRL);
+	else
+		ReceiveText->addstr(s, FTextBase::CTRL);
 }
 
 static const char cutnumbers[] = "T12345678N";
@@ -225,18 +231,24 @@ chars/sec:    %f",
 			num_cps_chars / (xmttime - overhead));
 	LOG_INFO("%s", results);
 	strcat(results, "\n");
-	ReceiveText->add(results, FTextBase::ALTR);
+	if (active_modem->get_mode() == MODE_IFKP)
+		ifkp_rx_text->add(results, FTextBase::ALTR);
+	else
+		ReceiveText->add(results, FTextBase::ALTR);
 	PERFORM_CPS_TEST = false;
 }
 
 static void pCPS_TEST(std::string &s, size_t &i, size_t endbracket)
 {
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_tx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		s.clear();
 		return;
 	}
@@ -250,7 +262,7 @@ static void pCPS_TEST(std::string &s, size_t &i, size_t endbracket)
 	if (n <= 0) n = 10;
 	if (n > 100) n = 100;
 
-// sample count with 'n' characters 
+// sample count with 'n' characters
 	int s1[256];
 	for (int i = 0; i < 256; i++) s1[i] = 0;
 // converstion from sample count to milliseconds
@@ -285,7 +297,10 @@ static void pCPS_TEST(std::string &s, size_t &i, size_t endbracket)
 	}
 	if (!line_out.empty()) {
 		LOG_INFO("%s", line_out.c_str());
-		ReceiveText->add(line_out.c_str(), FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add(line_out.c_str(), FTextBase::ALTR);
+		else
+			ReceiveText->add(line_out.c_str(), FTextBase::ALTR);
 	}
 	return;
 }
@@ -293,11 +308,14 @@ static void pCPS_TEST(std::string &s, size_t &i, size_t endbracket)
 static void pCPS_FILE(std::string &s, size_t &i, size_t endbracket)
 {
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		s.clear();
 		return;
 	}
@@ -314,7 +332,10 @@ static void pCPS_FILE(std::string &s, size_t &i, size_t endbracket)
 			}
 			s.clear();
 			fclose(toadd);
-			TransmitText->clear();
+			if (active_modem->get_mode() == MODE_IFKP)
+				ifkp_tx_text->clear();
+			else
+				TransmitText->clear();
 			testfilename = fname;
 
 			stopMacroTimer();
@@ -331,7 +352,10 @@ static void pCPS_FILE(std::string &s, size_t &i, size_t endbracket)
 		} else {
 			string resp = "Could not locate ";
 			resp.append(fname).append("\n");
-			ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+			if (active_modem->get_mode() == MODE_IFKP)
+				ifkp_rx_text->add(resp.c_str(), FTextBase::ALTR);
+			else
+				ReceiveText->add(resp.c_str(), FTextBase::ALTR);
 			LOG_WARN("%s not found", fname.c_str());
 			s.replace(i, endbracket - i + 1, "");
 			PERFORM_CPS_TEST = false;
@@ -345,11 +369,14 @@ static void pCPS_FILE(std::string &s, size_t &i, size_t endbracket)
 static void pCPS_STRING(std::string &s, size_t &i, size_t endbracket)
 {
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		s.clear();
 		return;
 	}
@@ -363,7 +390,10 @@ static void pCPS_STRING(std::string &s, size_t &i, size_t endbracket)
 		p = buffer.find("\\n");
 	}
 	if (buffer.length()) {
-		TransmitText->clear();
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_tx_text->clear();
+		else
+			TransmitText->clear();
 
 		stopMacroTimer();
 		active_modem->set_stopflag(false);
@@ -380,7 +410,10 @@ static void pCPS_STRING(std::string &s, size_t &i, size_t endbracket)
 		string resp = "Text not specified";
 		LOG_WARN("%s", resp.c_str());
 		resp.append("\n");
-		ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add(resp.c_str(), FTextBase::ALTR);
+		else
+			ReceiveText->add(resp.c_str(), FTextBase::ALTR);
 		PERFORM_CPS_TEST = false;
 	}
 }
@@ -388,11 +421,14 @@ static void pCPS_STRING(std::string &s, size_t &i, size_t endbracket)
 static void pCPS_N(std::string &s, size_t &i, size_t endbracket)
 {
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		s.clear();
 		return;
 	}
@@ -418,7 +454,10 @@ static void pCPS_N(std::string &s, size_t &i, size_t endbracket)
 		else buffer += ' ';
 	}
 
-	TransmitText->clear();
+	if (active_modem->get_mode() == MODE_IFKP)
+		ifkp_tx_text->clear();
+	else
+		TransmitText->clear();
 
 	stopMacroTimer();
 	active_modem->set_stopflag(false);
@@ -438,11 +477,14 @@ static void pWAV_TEST(std::string &s, size_t &i, size_t endbracket)
 {
 	s.clear();
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		return;
 	}
 	testfilename = "internal string";
@@ -459,11 +501,14 @@ static void pWAV_TEST(std::string &s, size_t &i, size_t endbracket)
 static void pWAV_N(std::string &s, size_t &i, size_t endbracket)
 {
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		s.clear();
 		return;
 	}
@@ -489,7 +534,10 @@ static void pWAV_N(std::string &s, size_t &i, size_t endbracket)
 		else buffer += ' ';
 	}
 
-	TransmitText->clear();
+	if (active_modem->get_mode() == MODE_IFKP)
+		ifkp_tx_text->clear();
+	else
+		TransmitText->clear();
 
 	stopMacroTimer();
 	active_modem->set_stopflag(false);
@@ -504,11 +552,14 @@ static void pWAV_N(std::string &s, size_t &i, size_t endbracket)
 static void pWAV_FILE(std::string &s, size_t &i, size_t endbracket)
 {
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		s.clear();
 		return;
 	}
@@ -525,7 +576,10 @@ static void pWAV_FILE(std::string &s, size_t &i, size_t endbracket)
 			}
 			s.clear();
 			fclose(toadd);
-			TransmitText->clear();
+			if (active_modem->get_mode() == MODE_IFKP)
+				ifkp_tx_text->clear();
+			else
+				TransmitText->clear();
 			testfilename = fname;
 
 			stopMacroTimer();
@@ -539,7 +593,10 @@ static void pWAV_FILE(std::string &s, size_t &i, size_t endbracket)
 		} else {
 			string resp = "Could not locate ";
 			resp.append(fname).append("\n");
-			ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+			if (active_modem->get_mode() == MODE_IFKP)
+				ifkp_rx_text->add(resp.c_str(), FTextBase::ALTR);
+			else
+				ReceiveText->add(resp.c_str(), FTextBase::ALTR);
 			LOG_WARN("%s not found", fname.c_str());
 			s.replace(i, endbracket - i + 1, "");
 			PERFORM_CPS_TEST = false;
@@ -553,11 +610,14 @@ static void pWAV_FILE(std::string &s, size_t &i, size_t endbracket)
 static void pWAV_STRING(std::string &s, size_t &i, size_t endbracket)
 {
 	trx_mode id = active_modem->get_mode();
-	if ( id == MODE_SSB || id == MODE_WWV || 
+	if ( id == MODE_SSB || id == MODE_WWV ||
 		id == MODE_ANALYSIS || id == MODE_FFTSCAN ||
 		id == MODE_WEFAX_576 || id == MODE_WEFAX_288 ||
 		id == MODE_SITORB || id == MODE_NAVTEX ) {
-		ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add("Mode not supported\n", FTextBase::ALTR);
+		else
+			ReceiveText->add("Mode not supported\n", FTextBase::ALTR);
 		s.clear();
 		return;
 	}
@@ -571,7 +631,10 @@ static void pWAV_STRING(std::string &s, size_t &i, size_t endbracket)
 		p = buffer.find("\\n");
 	}
 	if (buffer.length()) {
-		TransmitText->clear();
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_tx_text->clear();
+		else
+			TransmitText->clear();
 
 		stopMacroTimer();
 		active_modem->set_stopflag(false);
@@ -585,7 +648,10 @@ static void pWAV_STRING(std::string &s, size_t &i, size_t endbracket)
 		string resp = "Text not specified";
 		LOG_WARN("%s", resp.c_str());
 		resp.append("\n");
-		ReceiveText->add(resp.c_str(), FTextBase::ALTR);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->add(resp.c_str(), FTextBase::ALTR);
+		else
+			ReceiveText->add(resp.c_str(), FTextBase::ALTR);
 		PERFORM_CPS_TEST = false;
 	}
 }
@@ -986,7 +1052,7 @@ static void pTxQueIDLE(std::string &s, size_t &i, size_t endbracket)
 }
 
 static bool useTune = false;
-static int  tuneTime = 0;
+static float  tuneTime = 0;
 
 static void pTUNE(std::string &s, size_t &i, size_t endbracket)
 {
@@ -1042,7 +1108,7 @@ static void pNRSID(std::string &s, size_t &i, size_t endbracket)
 }
 
 static bool useWait = false;
-static int  waitTime = 0;
+static float  waitTime = 0;
 
 static void pWAIT(std::string &s, size_t &i, size_t endbracket)
 {
@@ -1050,10 +1116,10 @@ static void pWAIT(std::string &s, size_t &i, size_t endbracket)
 		s.replace(i, endbracket - i + 1, "");
 		return;
 	}
-	int number;
+	float number;
 	std::string sTime = s.substr(i+6, endbracket - i - 6);
 	if (sTime.length() > 0) {
-		sscanf(sTime.c_str(), "%d", &number);
+		sscanf(sTime.c_str(), "%f", &number);
 		useWait = true;
 		waitTime = number;
 	}
@@ -1069,12 +1135,12 @@ static void doneWAIT(void *)
 
 static void doWAIT(std::string s)
 {
-	int number;
+	float number;
 	std::string sTime = s.substr(7, s.length() - 8);
 	if (sTime.length() > 0) {
-		sscanf(sTime.c_str(), "%d", &number);
+		sscanf(sTime.c_str(), "%f", &number);
 		Qwait_time = number;
-		Fl::add_timeout (number * 1.0, doneWAIT);
+		Fl::add_timeout (number, doneWAIT);
 	} else
 		Qwait_time = 0;
 }
@@ -1090,6 +1156,27 @@ static void pTxQueWAIT(std::string &s, size_t &i, size_t endbracket)
 	s.replace(i, endbracket - i + 1, "^!");
 }
 
+static void doRxWAIT(std::string s)
+{
+	float number = 0;
+	std::string sTime = s.substr(7, s.length() - 8);
+	if (sTime.length() > 0) {
+		sscanf(sTime.c_str(), "%f", &number);
+		macro_rx_wait = true;
+		Fl::add_timeout(number, rx_que_continue);
+	}
+}
+
+static void pRxQueWAIT(std::string &s, size_t &i, size_t endbracket)
+{
+	if (within_exec) {
+		s.replace(i, endbracket - i + 1, "");
+		return;
+	}
+	struct CMDS cmd = { s.substr(i, endbracket - i + 1), doRxWAIT };
+	push_rxcmd(cmd);
+	s.replace(i, endbracket - i + 1, "");
+}
 
 static void pINFO1(std::string &s, size_t &i, size_t endbracket)
 {
@@ -1108,7 +1195,10 @@ static void pCLRRX(std::string &s, size_t &i, size_t endbracket)
 		return;
 	}
 	s.replace( i, 7, "" );
-	ReceiveText->clear();
+	if (active_modem->get_mode() == MODE_IFKP)
+		ifkp_rx_text->clear();
+	else
+		ReceiveText->clear();
 }
 
 static void pCLRTX(std::string &s, size_t &i, size_t endbracket)
@@ -1119,7 +1209,10 @@ static void pCLRTX(std::string &s, size_t &i, size_t endbracket)
 	}
 	s.replace( i, 7, "" );
 	queue_reset();
-	TransmitText->clear();
+	if (active_modem->get_mode() == MODE_IFKP)
+		ifkp_tx_text->clear();
+	else
+		TransmitText->clear();
 }
 
 static void pFOCUS(std::string &s, size_t &i, size_t endbracket)
@@ -1127,7 +1220,10 @@ static void pFOCUS(std::string &s, size_t &i, size_t endbracket)
 	if (!within_exec) {
 		if (qsoFreqDisp->is_reversed_colors()) {
 			qsoFreqDisp->restore_colors();
-			TransmitText->take_focus();
+			if (active_modem->get_mode() == MODE_IFKP)
+				ifkp_tx_text->take_focus();
+			else
+				TransmitText->take_focus();
 		} else {
 			qsoFreqDisp->take_focus();
 			qsoFreqDisp->reverse_colors();
@@ -1161,7 +1257,10 @@ static void pQSYPLUS(std::string &s, size_t &i, size_t endbracket)
 
 static void pCALL(std::string &s, size_t &i, size_t endbracket)
 {
-	s.replace( i, 6, inpCall->value() );
+	string call = inpCall->value();
+	if (active_modem->get_mode() == MODE_IFKP && progdefaults.ifkp_lowercase_call)
+		for (size_t n = 0; n < call.length(); n++) call[n] = tolower(call[n]);
+	s.replace( i, 6, call );
 }
 
 static void pGET(std::string &s, size_t &i, size_t endbracket)
@@ -1176,7 +1275,7 @@ static void pFREQ(std::string &s, size_t &i, size_t endbracket)
 }
 
 static void pBAND(std::string &s, size_t &i, size_t endbracket)
-{ 
+{
         s.replace( i, 6, band_name( band( wf->rfcarrier() ) ) );
 }
 
@@ -1213,7 +1312,10 @@ static void pRST(std::string &s, size_t &i, size_t endbracket)
 
 static void pMYCALL(std::string &s, size_t &i, size_t endbracket)
 {
-	s.replace( i, 8, inpMyCallsign->value() );
+	string call = inpMyCallsign->value();
+	if (active_modem->get_mode() == MODE_IFKP && progdefaults.ifkp_lowercase)
+		for (size_t n = 0; n < call.length(); n++) call[n] = tolower(call[n]);
+	s.replace( i, 8, call );
 }
 
 static void pMYLOC(std::string &s, size_t &i, size_t endbracket)
@@ -1237,8 +1339,8 @@ static void pMYRST(std::string &s, size_t &i, size_t endbracket)
 }
 
 static void pANTENNA(std::string &s, size_t &i, size_t endbracket)
-{ 
-        s.replace( i, 9, progdefaults.myAntenna.c_str() );  
+{
+        s.replace( i, 9, progdefaults.myAntenna.c_str() );
 }
 
 static void pLDT(std::string &s, size_t &i, size_t endbracket)
@@ -2303,6 +2405,7 @@ static void doGOFREQ(std::string s)
 		if (number > progdefaults.HighFreqCutoff)
 			number = progdefaults.HighFreqCutoff;
 		active_modem->set_freq(number);
+		wf->redraw();
 	}
 	que_ok = true;
 }
@@ -3006,10 +3109,17 @@ void Rx_queue_execute()
 		cmd.cmd.erase(0,2);
 		cmd.cmd.insert(0,"<!");
 		cmd.fp(cmd.cmd);
+		if (macro_rx_wait) return;
 	}
 	return;
 }
 
+void rx_que_continue(void *)
+{
+	macro_rx_wait = false;
+	Rx_queue_execute();
+}
+
 struct MTAGS { const char *mTAG; void (*fp)(std::string &, size_t&, size_t );};
 
 static const MTAGS mtags[] = {
@@ -3124,6 +3234,7 @@ static const MTAGS mtags[] = {
 	{"<WX>",		pWX},
 	{"<WX:",		pWX2},
 	{"<IMAGE:",		pTxQueIMAGE},
+// Tx Delayed action
 	{"<!WPM:",		pTxQueWPM},
 	{"<!RISE:",		pTxQueRISETIME},
 	{"<!PRE:",		pTxQuePRE},
@@ -3138,7 +3249,7 @@ static const MTAGS mtags[] = {
 	{"<!FILWID:",	pTxQueFILWID},
 	{"<!TXATTEN:",	pTxQueTXATTEN},
 	{"<!RIGCAT:",	pTxQueRIGCAT},
-
+// Rx After action
 	{"<@MODEM:",	pRxQueMODEM},
 	{"<@RIGCAT:",	pRxQueRIGCAT},
 	{"<@GOFREQ:",	pRxQueGOFREQ},
@@ -3146,6 +3257,7 @@ static const MTAGS mtags[] = {
 	{"<@RIGMODE:",	pRxQueRIGMODE},
 	{"<@FILWID:",	pRxQueFILWID},
 	{"<@TXRSID:",	pRxQueTXRSID},
+	{"<@WAIT:",     pRxQueWAIT},
 
 	{0, 0}
 };
@@ -3240,7 +3352,10 @@ void MACROTEXT::loadDefault()
 		LOG_INFO("%s", Macroset.c_str());
 		Macroset.insert(0, "\n");
 		Macroset.append("\n");
-		ReceiveText->addstr(Macroset);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_rx_text->addstr(Macroset);
+		else
+			ReceiveText->addstr(Macroset);
 	}
 }
 
@@ -3266,7 +3381,10 @@ void MACROTEXT::openMacroFile()
 		if (progdefaults.DisplayMacroFilename) {
 			string Macroset;
 			Macroset.assign("\nLoaded macros: ").append(progStatus.LastMacroFile).append("\n");
-			ReceiveText->addstr(Macroset);
+			if (active_modem->get_mode() == MODE_IFKP)
+				ifkp_rx_text->addstr(Macroset);
+			else
+				ReceiveText->addstr(Macroset);
 		}
 	}
 }
@@ -3404,7 +3522,10 @@ std::string MACROTEXT::expandMacro(std::string &s, bool recurse = false)
 		expanded.erase(idx, 2);
 		expanded.append("^r");
 	}
-	
+
+	if (!TransmitON && !Rx_cmds.empty())
+		Fl::add_timeout(0, rx_que_continue);
+
 	return expanded;
 }
 
@@ -3464,44 +3585,66 @@ static void set_button(Fl_Button* button, bool value)
 void MACROTEXT::timed_execute()
 {
 	queue_reset();
-	TransmitText->clear();
+	if (active_modem->get_mode() == MODE_IFKP)
+		ifkp_tx_text->clear();
+	else
+		TransmitText->clear();
 	if (!rx_only) {
 		text2send = expandMacro(exec_string);
-		TransmitText->add_text(text2send);
+		if (active_modem->get_mode() == MODE_IFKP)
+			ifkp_tx_text->add_text(text2send);
+		else
+			TransmitText->add_text(text2send);
 		exec_string.clear();
 		active_modem->set_stopflag(false);
 		start_tx();
 	}
 }
 
+bool wait_execute = false;
+
 void MACROTEXT::execute(int n)
 {
+	while (wait_execute) { MilliSleep(10); }
+	wait_execute = true;
+
 	mNbr = n;
 	text2send = expandMacro(text[n]);
-	
+
 	if (timed_exec) {
 		progStatus.repeatMacro = -1;
 		exec_string = text[n];
 		timed_exec = false;
 		startTimedExecute(name[n]);
+		wait_execute = false;
 		return;
 	}
-	
+
+	trx_mode mode = active_modem->get_mode();
+
 	if (!rx_only) {
-		if (progStatus.repeatMacro == -1)
-			TransmitText->add_text( text2send );
-		else {
+		if (progStatus.repeatMacro == -1) {
+			if (mode == MODE_IFKP) {
+				ifkp_tx_text->add_text( text2send );
+			} else {
+				TransmitText->add_text( text2send );
+			}
+		} else {
 			size_t p = std::string::npos;
 			text2send = text[n];
 			while ((p = text2send.find('<')) != std::string::npos)
 				text2send[p] = '[';
 			while ((p = text2send.find('>')) != std::string::npos)
 				text2send[p] = ']';
-			TransmitText->add_text( text2send );
+			if (mode == MODE_IFKP) {
+				ifkp_tx_text->add_text( text2send );
+			} else {
+				TransmitText->add_text( text2send );
+			}
 		}
 	}
 	text2send.clear();
-	
+
 	if (ToggleTXRX) {
 		text2send.clear();
 		if (!wf->xmtrcv->value()) {
@@ -3510,27 +3653,31 @@ void MACROTEXT::execute(int n)
 				Fl::add_timeout(idleTime, idleTimer);
 		} else
 			REQ(set_button, wf->xmtrcv, false);
+		wait_execute = false;
 		return;
 	}
 	if (useWait && waitTime > 0) {
 		Fl::add_timeout(waitTime, finishWait);
 		useWait = false;
+		wait_execute = false;
 		return;
 	}
 	if (useTune && tuneTime > 0) {
 		trx_tune();
 		Fl::add_timeout(tuneTime, finishTune);
 		useTune = false;
+		wait_execute = false;
 		return;
 	}
 	if ( TransmitON ) {
 		if (macro_idle_on && idleTime > 0)
 			Fl::add_timeout(idleTime, idleTimer);
-		
+
 		active_modem->set_stopflag(false);
 		start_tx();
 		TransmitON = false;
 	}
+	wait_execute = false;
 }
 
 void MACROTEXT::repeat(int n)
@@ -3564,7 +3711,7 @@ static std::string mtext =
 ";
 
 void MACROTEXT::saveMacros(const std::string& fname) {
-	
+
 	std::string work;
 	std::string output;
 	char temp[200];
@@ -3583,7 +3730,7 @@ void MACROTEXT::saveMacros(const std::string& fname) {
 		output.append(work).append("\n");
 	}
 	UTF8_writefile(fname.c_str(), output);
-	
+
 	changed = false;
 }
 
