@@ -1052,22 +1052,6 @@ public:
 	}
 };
 
-
-class Main_get_freq : public xmlrpc_c::method
-{
-public:
-	Main_get_freq()
-	{
-		_signature = "d:n";
-		_help = "Returns the RF carrier frequency.";
-	}
-	void execute(const xmlrpc_c::paramList& params, xmlrpc_c::value* retval)
-	{
-		double rfc = wf->rfcarrier();
-		*retval = xmlrpc_c::value_double(rfc);
-	}
-};
-
 void xmlrpc_set_qsy(long long rfc)
 {
 	wf->rfcarrier(rfc);
@@ -1751,7 +1735,7 @@ class Main_get_char_timing : public xmlrpc_c::method
 public:
 	Main_get_char_timing()
 	{
-		_signature = "n:6";
+		_signature = "n:i";
 		_help = "Input: value of character. Returns transmit duration for specified character (samples:sample rate).";
 	}
 	void execute(const xmlrpc_c::paramList& params, xmlrpc_c::value* retval)
@@ -1814,51 +1798,7 @@ public:
 			chsamples = active_modem->char_samples;
 			over_head = active_modem->ovhd_samples;
 		} else if(psk_8_flag) { // This doens't seem to work with the MFSK modes
-#if 0
-			int n = progdefaults.busyChannelSeconds;
-			int sr = active_modem->get_samplerate();
-			int index = 0;
-			int count = 0;
-			int test_array[] = { 2, 8, 40, 64, 104, 112, 0 };
-
-            over_head = number_of_samples("");
-
-			for(index = 0; index < 6; index++) {
-				chsamples = number_of_samples(string(n, test_array[index])) - over_head;
-				chsamples /= n;
-				printf("%c = %3.8f ", test_array[index], (float)((float) chsamples / (float) sr));
-			}
-			printf("\n");
-
-#else
 			int n = 16;
-
-			switch(id) {
-				case MODE_8PSK250:
-					n = 16;
-					break;
-
-				case MODE_8PSK500:
-					n = 33;
-					break;
-
-				case MODE_8PSK1000:
-					n = 21;
-					break;
-
-				case MODE_8PSK1200:
-					n = 18;
-					break;
-
-				case MODE_8PSK1333:
-					n = 12;
-					break;
-
-				default:
-					n = 16;
-			}
-
-#endif
             over_head = number_of_samples("");
 			chsamples = number_of_samples(string(n, character)) - over_head;
 			chsamples /= n;
@@ -1894,7 +1834,7 @@ class Main_get_tx_timing : public xmlrpc_c::method
 public:
 	Main_get_tx_timing()
 	{
-		_signature = "n:6";
+		_signature = "n:s";
 		_help = "Returns transmit duration for test string (samples:sample rate:secs).";
 	}
 	void execute(const xmlrpc_c::paramList& params, xmlrpc_c::value* retval)
@@ -1986,6 +1926,21 @@ public:
 	}
 };
 
+class Rig_get_freq : public xmlrpc_c::method
+{
+public:
+	Rig_get_freq()
+	{
+		_signature = "d:n";
+		_help = "Returns the RF carrier frequency.";
+	}
+	void execute(const xmlrpc_c::paramList& params, xmlrpc_c::value* retval)
+	{
+		double rfc = wf->rfcarrier();
+		*retval = xmlrpc_c::value_double(rfc);
+	}
+};
+
 class Rig_set_smeter : public xmlrpc_c::method
 {
 public:
@@ -2312,6 +2267,11 @@ class Main_set_rig_mode : public Rig_set_mode
 public:
 	Main_set_rig_mode() { _help = "[DEPRECATED; use rig.set_mode"; }
 };
+class Main_get_freq : public Rig_get_freq
+{
+public:
+	Main_get_freq() {_help = "[DEPRECATED; use rig.get_frequency"; }
+};
 class Main_get_rig_modes : public Rig_get_modes
 {
 public:
@@ -2502,7 +2462,7 @@ class Log_set_rst_in : public xmlrpc_c::method
 public:
 	Log_set_rst_in()
 	{
-		_signature = "s:n";
+		_signature = "n:s";
 		_help = "Sets the RST(r) field contents.";
 	}
 	void execute(const xmlrpc_c::paramList& params, xmlrpc_c::value* retval)
@@ -2533,7 +2493,7 @@ class Log_set_rst_out : public xmlrpc_c::method
 public:
 	Log_set_rst_out()
 	{
-		_signature = "s:n";
+		_signature = "n:s";
 		_help = "Sets the RST(s) field contents.";
 	}
 	void execute(const xmlrpc_c::paramList& params, xmlrpc_c::value* retval)
@@ -3035,8 +2995,6 @@ public:
 
 // =============================================================================
 
-extern Fl_Button* btnAutoSpot; // FIXME: export in fl_digi.h
-
 class Spot_get_auto : public xmlrpc_c::method
 {
 public:
@@ -3063,7 +3021,7 @@ public:
 	{
 		XMLRPC_LOCK;
 		bool v = btnAutoSpot->value();
-		REQ(set_button, btnAutoSpot, params.getBoolean(0));
+		REQ(set_button, (Fl_Button *) btnAutoSpot, params.getBoolean(0));
 		*retval = xmlrpc_c::value_boolean(v);
 	}
 };
@@ -3080,7 +3038,7 @@ public:
 	{
 		XMLRPC_LOCK;
 		bool v = !btnAutoSpot->value();
-		REQ(set_button, btnAutoSpot, v);
+		REQ(set_button, (Fl_Button *) btnAutoSpot, v);
 		*retval = xmlrpc_c::value_boolean(v);
 	}
 };
@@ -3460,13 +3418,14 @@ ELEM_(Rig_set_name, "rig.set_name")								\
 ELEM_(Rig_get_name, "rig.get_name")								\
 ELEM_(Rig_set_frequency, "rig.set_frequency")						\
 ELEM_(Rig_set_smeter, "rig.set_smeter")							\
-ELEM_(Rig_set_pwrmeter, "rig.set_pwrmeter")							\
+ELEM_(Rig_set_pwrmeter, "rig.set_pwrmeter")						\
 ELEM_(Rig_set_modes, "rig.set_modes")								\
 ELEM_(Rig_set_mode, "rig.set_mode")								\
 ELEM_(Rig_get_modes, "rig.get_modes")								\
 ELEM_(Rig_get_mode, "rig.get_mode")								\
 ELEM_(Rig_set_bandwidths, "rig.set_bandwidths")					\
 ELEM_(Rig_set_bandwidth, "rig.set_bandwidth")						\
+ELEM_(Rig_get_freq, "rig.get_frequency")							\
 ELEM_(Rig_get_bandwidth, "rig.get_bandwidth")						\
 ELEM_(Rig_get_bandwidths, "rig.get_bandwidths")					\
 ELEM_(Rig_get_notch, "rig.get_notch")								\
@@ -3482,7 +3441,7 @@ ELEM_(Log_get_name, "log.get_name")								\
 ELEM_(Log_get_rst_in, "log.get_rst_in")							\
 ELEM_(Log_get_rst_out, "log.get_rst_out")							\
 ELEM_(Log_set_rst_in, "log.set_rst_in")							\
-ELEM_(Log_set_rst_out, "log.set_rst_out")						\
+ELEM_(Log_set_rst_out, "log.set_rst_out")							\
 ELEM_(Log_get_serial_number, "log.get_serial_number")			\
 ELEM_(Log_set_serial_number, "log.set_serial_number")			\
 ELEM_(Log_get_serial_number_sent, "log.get_serial_number_sent")	\
@@ -3502,6 +3461,8 @@ ELEM_(Log_set_call, "log.set_call")								\
 ELEM_(Log_set_name, "log.set_name")								\
 ELEM_(Log_set_qth, "log.set_qth")									\
 ELEM_(Log_set_locator, "log.set_locator")							\
+ELEM_(Log_set_rst_in, "log.set_rst_in")							\
+ELEM_(Log_set_rst_out, "log.set_rst_out")							\
 \
 ELEM_(Io_in_use, "io.in_use")	          						\
 ELEM_(Io_enable_kiss, "io.enable_kiss")							\
