@@ -130,7 +130,7 @@ cFreqControl::cFreqControl(int x, int y, int w, int h, const char *lbl):
 
 	minVal = 0;
 	double fmaxval = (pow(10, nD) - 1) * precision;
-	long int UMAX = (long int)(pow(2, 31) - 1);
+	long int UMAX = maximum();
 	if (fmaxval > UMAX) fmaxval = UMAX;
 	maxVal = fmaxval;
 	fmaxval /= 1000.0;
@@ -153,7 +153,7 @@ cFreqControl::cFreqControl(int x, int y, int w, int h, const char *lbl):
 			fcWidth,
 			fcHeight,
 			" ");
-		Digit[n]->box(FL_FLAT_BOX); 
+		Digit[n]->box(FL_FLAT_BOX);
 		Digit[n]->labelfont(font_number);
 		Digit[n]->labelcolor(ONCOLOR);
 		Digit[n]->color(OFFCOLOR, SELCOLOR);
@@ -179,7 +179,7 @@ cFreqControl::cFreqControl(int x, int y, int w, int h, const char *lbl):
 			fcWidth,
 			fcHeight,
 			" ");
-		Digit[n]->box(FL_FLAT_BOX); 
+		Digit[n]->box(FL_FLAT_BOX);
 		Digit[n]->labelfont(font_number);
 		Digit[n]->labelcolor(ONCOLOR);
 		Digit[n]->color(OFFCOLOR, SELCOLOR);
@@ -273,7 +273,7 @@ void cFreqControl::SetONOFFCOLOR( Fl_Color ONcolor, Fl_Color OFFcolor)
 	redraw();
 }
 
-void cFreqControl::SetONCOLOR (uchar r, uchar g, uchar b) 
+void cFreqControl::SetONCOLOR (uchar r, uchar g, uchar b)
 {
 	ONCOLOR = fl_rgb_color (r, g, b);
 	REVOFFCOLOR = ONCOLOR;
@@ -299,7 +299,7 @@ void cFreqControl::SetONCOLOR (uchar r, uchar g, uchar b)
 	redraw();
 }
 
-void cFreqControl::SetOFFCOLOR (uchar r, uchar g, uchar b) 
+void cFreqControl::SetOFFCOLOR (uchar r, uchar g, uchar b)
 {
 	OFFCOLOR = fl_rgb_color (r, g, b);
 	REVONCOLOR = OFFCOLOR;
@@ -337,6 +337,12 @@ void cFreqControl::value(long lv)
 	updatevalue();
 }
 
+long int cFreqControl::maximum(void)
+{
+	return (long int)(pow(2, 31) - 1);
+}
+
+
 void cFreqControl::restore_colors()
 {
 	enable_arrow_keys = false;
@@ -403,13 +409,15 @@ int cFreqControl::handle(int event)
 	int d;
 
 	switch (event) {
+
 	case FL_FOCUS:
 		return 1;
 	case FL_UNFOCUS:
 		return 1;
 	case FL_ENTER:
 		fw = Fl::focus();
-		take_focus();
+		if (fw != NULL) // if NULL then fldigi did not have focus
+			take_focus();
 		break;
 	case FL_LEAVE:
 		if (fw)
@@ -420,6 +428,7 @@ int cFreqControl::handle(int event)
 		updatevalue();
 		return 1;
 		break;
+
 	case FL_KEYBOARD:
 		switch (d = Fl::event_key()) {
 		case FL_Right:
@@ -626,7 +635,7 @@ void cFreqControl::set_ndigits(int nbr)
 			fcWidth,
 			fcHeight,
 			" ");
-		Digit[n]->box(FL_FLAT_BOX); 
+		Digit[n]->box(FL_FLAT_BOX);
 		Digit[n]->labelfont(font_number);
 		Digit[n]->labelcolor(ONCOLOR);
 		Digit[n]->color(OFFCOLOR, SELCOLOR);
@@ -654,7 +663,7 @@ void cFreqControl::set_ndigits(int nbr)
 			fcWidth,
 			fcHeight,
 			" ");
-		Digit[n]->box(FL_FLAT_BOX); 
+		Digit[n]->box(FL_FLAT_BOX);
 		Digit[n]->labelfont(font_number);
 		Digit[n]->labelcolor(ONCOLOR);
 		Digit[n]->color(OFFCOLOR, SELCOLOR);
