@@ -46,6 +46,7 @@
 #include "debug.h"
 #include "nullmodem.h"
 #include "macros.h"
+#include "rigsupport.h"
 
 #if BENCHMARK_MODE
 #  include "benchmark.h"
@@ -81,13 +82,13 @@ static int	_trx_tune;
 #define NUMMEMBUFS 1024
 static ringbuffer<double> trxrb(ceil2(NUMMEMBUFS * SCBLOCKSIZE));
 static float fbuf[SCBLOCKSIZE];
-bool    bHistory = false;
-bool    bHighSpeed = false;
+bool	bHistory = false;
+bool	bHighSpeed = false;
 static  double hsbuff[SCBLOCKSIZE];
 
 static bool trxrunning = false;
 
-bool    rx_only = false;
+bool	rx_only = false;
 
 #include "tune.cxx"
 
@@ -194,46 +195,48 @@ void trx_xmit_wfall_queue(int samplerate, const double* buf, size_t len)
 
 void trx_trx_receive_loop()
 {
-    size_t  numread;
-    int  current_samplerate;
-    assert(powerof2(SCBLOCKSIZE));
+	size_t  numread;
+	int  current_samplerate;
+	assert(powerof2(SCBLOCKSIZE));
 
-    if (unlikely(!active_modem)) {
+	if (unlikely(!active_modem)) {
 	MilliSleep(10);
 	return;
-    }
+	}
 
 #if BENCHMARK_MODE
-    do_benchmark();
-    trx_state = STATE_ENDED;
-    return;
+	do_benchmark();
+	trx_state = STATE_ENDED;
+	return;
 #endif
 
-    if (unlikely(!scard)) {
+	if (unlikely(!scard)) {
 	MilliSleep(10);
 	return;
-    }
-
-    try {
-	current_samplerate = active_modem->get_samplerate();
-	if (scard->Open(O_RDONLY, current_samplerate))
-	    REQ(sound_update, progdefaults.btnAudioIOis);
-    }
-    catch (const SndException& e) {
-	LOG_ERROR("%s. line: %i", e.what(), __LINE__);
-	put_status(e.what(), 5);
-	scard->Close();
-	if (e.error() == EBUSY && progdefaults.btnAudioIOis == SND_IDX_PORT) {
-	    sound_close();
-	    sound_init();
 	}
-	MilliSleep(1000);
-	return;
-    }
-    active_modem->rx_init();
 
-    ringbuffer<double>::vector_type rbvec[2];
-    rbvec[0].buf = rbvec[1].buf = 0;
+	try {
+		current_samplerate = active_modem->get_samplerate();
+		if (scard->Open(O_RDONLY, current_samplerate))
+			REQ(sound_update, progdefaults.btnAudioIOis);
+	}
+	catch (const SndException& e) {
+		LOG_ERROR("%s. line: %i", e.what(), __LINE__);
+		put_status(e.what(), 5);
+		scard->Close();
+//	if (e.error() == EBUSY && progdefaults.btnAudioIOis == SND_IDX_PORT) {
+		if (progdefaults.btnAudioIOis == SND_IDX_PORT) {
+			sound_close();
+			sound_init();
+		}
+
+		MilliSleep(1000);
+		return;
+	}
+	active_modem->rx_init();
+
+	ringbuffer<double>::vector_type rbvec[2];
+	rbvec[0].buf = rbvec[1].buf = 0;
 
 	while (1) {
 		try {
@@ -321,14 +324,14 @@ void trx_trx_transmit_loop()
 	if (active_modem) {
 
 		try {
-		    current_samplerate = active_modem->get_samplerate();
-		    scard->Open(O_WRONLY, current_samplerate);
+			current_samplerate = active_modem->get_samplerate();
+			scard->Open(O_WRONLY, current_samplerate);
 		}
 		catch (const SndException& e) {
-		    LOG_ERROR("%s. line: %i", e.what(), __LINE__);
-		    put_status(e.what(), 1);
-		    MilliSleep(10);
-		    return;
+			LOG_ERROR("%s. line: %i", e.what(), __LINE__);
+			put_status(e.what(), 1);
+			MilliSleep(10);
+			return;
 		}
 
 		if ((active_modem != ssb_modem) &&
@@ -368,7 +371,8 @@ void trx_trx_transmit_loop()
 					if (!progdefaults.DTMFstr.empty())
 						dtmf->send();
 					if (active_modem->tx_process() < 0)
-						trx_state = STATE_RX;
+						if (trx_state != STATE_ABORT)
+							trx_state = STATE_RX;
 				}
 				catch (const SndException& e) {
 					scard->Close();
@@ -379,7 +383,8 @@ void trx_trx_transmit_loop()
 				}
 			}
 		} else
-			trx_state = STATE_RX;
+			if (trx_state != STATE_ABORT)
+				trx_state = STATE_RX;
 
 		if (ReedSolomon->assigned(active_modem->get_mode()) &&
 			progdefaults.TransmitRSid &&
@@ -416,14 +421,14 @@ void trx_tune_loop()
 	}
 	if (active_modem) {
 		try {
-		    current_samplerate = active_modem->get_samplerate();
-		    scard->Open(O_WRONLY, current_samplerate);
+			current_samplerate = active_modem->get_samplerate();
+			scard->Open(O_WRONLY, current_samplerate);
 		}
 		catch (const SndException& e) {
-		    LOG_ERROR("%s. line: %i", e.what(), __LINE__);
-		    put_status(e.what(), 1);
-		    MilliSleep(10);
-		    return;
+			LOG_ERROR("%s. line: %i", e.what(), __LINE__);
+			put_status(e.what(), 1);
+			MilliSleep(10);
+			return;
 		}
 
 		push2talk->set(true);
@@ -491,20 +496,26 @@ void *trx_loop(void *args)
 			trx_state = STATE_ENDED;
 			// fall through
 		case STATE_ENDED:
+			REQ(set_flrig_ptt, 0);
 			return 0;
 		case STATE_RESTART:
+			REQ(set_flrig_ptt, 0);
 			trx_reset_loop();
 			break;
 		case STATE_NEW_MODEM:
+			REQ(set_flrig_ptt, 0);
 			trx_start_modem_loop();
 			break;
 		case STATE_TX:
+			REQ(set_flrig_ptt, 1);
 			trx_trx_transmit_loop();
 			break;
 		case STATE_TUNE:
+			REQ(set_flrig_ptt, 1);
 			trx_tune_loop();
 			break;
 		case STATE_RX:
+			REQ(set_flrig_ptt, 0);
 			trx_trx_receive_loop();
 			break;
 		default:
@@ -536,6 +547,7 @@ void trx_start_modem_loop()
 		active_modem->set_freq(new_freq);
 	trx_state = STATE_RX;
 	REQ(&waterfall::opmode, wf);
+	REQ(set599);
 
 	if (old_modem) {
 		*mode_info[old_modem->get_mode()].modem = 0;
@@ -567,7 +579,7 @@ void trx_reset_loop()
 #endif
 #if USE_PORTAUDIO
 	case SND_IDX_PORT:
-	    scard = new SoundPort(scDevice[0].c_str(), scDevice[1].c_str());
+		scard = new SoundPort(scDevice[0].c_str(), scDevice[1].c_str());
 		break;
 #endif
 #if USE_PULSEAUDIO
@@ -670,10 +682,20 @@ void trx_start(void)
 //=============================================================================
 void trx_close()
 {
+	int count = 1000;
+	active_modem->set_stopflag(true);
+	while (trx_state != STATE_RX && count--)
+		MilliSleep(10);
+	if (trx_state != STATE_RX) {
+		exit(1);
+	}
+	count = 1000;
 	trx_state = STATE_ABORT;
-	while (trx_state != STATE_ENDED)
-		MilliSleep(100);
-
+	while (trx_state != STATE_ENDED && count--)
+		MilliSleep(10);
+	if (trx_state != STATE_ENDED) {
+		exit(2);
+	}
 #if USE_NAMED_SEMAPHORES
 	if (sem_close(trx_sem) == -1)
 		LOG_PERROR("sem_close");
