@@ -39,13 +39,13 @@
 enum { OP_UNDO, OP_CUT, OP_COPY, OP_PASTE, OP_DELETE, OP_CLEAR, OP_SELECT_ALL };
 
 static Fl_Menu_Item cmenu[] = {
-	{ make_icon_label(_("Undo"), edit_undo_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Cut"), edit_cut_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Copy"), edit_copy_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Paste"), edit_paste_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Delete"), trash_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Clear"), edit_clear_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
-	{ make_icon_label(_("Select All"), edit_select_all_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Undo"), edit_undo_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Cut"), edit_cut_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Copy"), edit_copy_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Paste"), edit_paste_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Delete"), trash_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Clear"), edit_clear_icon), 0, 0, 0, FL_MENU_DIVIDER, _FL_MULTI_LABEL },
+	{ icons::make_icon_label(_("Select All"), edit_select_all_icon), 0, 0, 0, 0, _FL_MULTI_LABEL },
 	{ 0 }
 };
 static bool cmenu_init = false;
@@ -57,7 +57,7 @@ Fl_Input2::Fl_Input2(int x, int y, int w, int h, const char* l)
 	if (!cmenu_init) {
 		for (size_t i = 0; i < sizeof(cmenu)/sizeof(*cmenu) - 1; i++)
 			if (cmenu[i].labeltype() == _FL_MULTI_LABEL)
-				set_icon_label(&cmenu[i]);
+				icons::set_icon_label(&cmenu[i]);
 		cmenu_init = true;
 	}
 }
@@ -136,13 +136,13 @@ int Fl_Input2::handle(int event)
 	}
 
 	bool sel = position() != mark(), ro = readonly();
-	set_active(&cmenu[OP_UNDO], !ro);
-	set_active(&cmenu[OP_CUT], !ro && sel);
-	set_active(&cmenu[OP_COPY], sel);
-	set_active(&cmenu[OP_PASTE], !ro);
-	set_active(&cmenu[OP_DELETE], !ro && sel);
-	set_active(&cmenu[OP_CLEAR], !ro && size());
-	set_active(&cmenu[OP_SELECT_ALL], size());
+	icons::set_active(&cmenu[OP_UNDO], !ro);
+	icons::set_active(&cmenu[OP_CUT], !ro && sel);
+	icons::set_active(&cmenu[OP_COPY], sel);
+	icons::set_active(&cmenu[OP_PASTE], !ro);
+	icons::set_active(&cmenu[OP_DELETE], !ro && sel);
+	icons::set_active(&cmenu[OP_CLEAR], !ro && size());
+	icons::set_active(&cmenu[OP_SELECT_ALL], size());
 
 	take_focus();
 	window()->cursor(FL_CURSOR_DEFAULT);
